BaseDecoder class

Contains base classes for 8bit codecs Provides a simple decoder.

Inheritance
Implementers

Constructors

BaseDecoder(String symbols, int startIndex, {bool allowInvalid = false})
Creates a new 8bit decoder.
const
BaseDecoder.withNonAsciiStartBlock(String startBlock, String symbols, int startIndex, {bool allowInvalid = false})
Creates a a base decoder with a non-ascii start block
const

Properties

allowInvalid → bool
Should invalid character codes be ignored?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startBlock → String?
The start pattern for partially non-Ascii compliant character sets like DOS-Latin-1 / cp-850.
final
startIndex → int
The index of the first non-ASCII character
final
symbols → String
The used symbols
final

Methods

bind(Stream<List<int>> stream) → Stream<String>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(List<int> input, [int start = 0, int? end]) → String
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<String, TT> other) → Converter<List<int>, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<String> sink) → ByteConversionSink
Starts a chunked conversion.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited