BaseDecoder constructor

const BaseDecoder(
  1. String symbols,
  2. int startIndex, {
  3. bool allowInvalid = false,
})

Creates a new 8bit decoder.

symbols contain all symbols different than UTF8 from the specified startIndex onwards.

The length of the symbols need to be 255 / 0xFF minus the startIndex.

Set allowInvalid to true in case invalid characters sequences should be at least readable.

Implementation

const BaseDecoder(this.symbols, this.startIndex, {this.allowInvalid = false})
    : startBlock = null,
      assert(symbols.length == 255 - startIndex, 'invalid length of symbols');