BaseEncoder class

Provides a simple 8bit encoder.

Inheritance
Implementers

Constructors

BaseEncoder(Map<int, int> encodingMap, int startIndex, {bool allowInvalid = false, int lowerEndIndex = -1})
Creates a new encoder.
const

Properties

allowInvalid → bool
Should invalid character codes be ignored?
final
encodingMap → Map<int, int>
All encodings
final
hashCode → int
The hash code for this object.
no setterinherited
lowerEndIndex → int
End index of the lower block.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
The index of the first non-ASCII character
final

Methods

bind(Stream<String> stream) → Stream<List<int>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String input, [int start = 0, int? end]) → List<int>
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<List<int>, TT> other) → Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<List<int>> sink) → StringConversionSink
Starts a chunked conversion.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createEncodingMap(String symbols, int startIndex) → Map<int, int>
Static helper function to generate a conversion map from a symbols string.