BaseDecoderSink class
Decoder sink for chunked conversion.
Compare BaseDecoder.startChunkedConversion(...).
- Inheritance
-
- Object
- ByteConversionSinkBase
- BaseDecoderSink
Constructors
- BaseDecoderSink(StringConversionSink sink, BaseDecoder decoder, {required bool allowInvalid})
- Creates a new basic decoder sink
Properties
- allowInvalid → bool
-
Should invalid character codes be ignored?
final
- decoder → BaseDecoder
-
The used decoder
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sink → StringConversionSink
-
The used string conversion sink
final
Methods
-
add(
List< int> chunk) → void -
Adds chunked data to this sink.
override
-
addSlice(
List< int> chunk, int start, int end, bool isLast) → void -
Adds the next
chunktothis.override -
close(
) → void -
Closes the sink.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited