BaseEncoderSink class
Encoder sink for chunked conversion.
Compare BaseEncoder.startChunkedConversion.
- Inheritance
-
- Object
- StringConversionSinkBase
- BaseEncoderSink
Constructors
- BaseEncoderSink(ByteConversionSink sink, BaseEncoder encoder)
- Creates a new basic encoder sink
Properties
- encoder → BaseEncoder
-
The used encoder
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sink → ByteConversionSink
-
The used byte conversion sink
final
Methods
-
add(
String str) → void -
Adds chunked data to this sink.
override
-
addSlice(
String str, int start, int end, bool isLast) → void -
Adds the next
chunktothis.override -
asStringSink(
) → ClosableStringSink -
Returns
thisas a ClosableStringSink.inherited -
asUtf8Sink(
bool allowMalformed) → ByteConversionSink -
Returns
thisas a sink that accepts UTF-8 input.inherited -
close(
) → void -
Closes the sink.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited